@@ -10,13 +10,18 @@ team = mcolors.ListedColormap([colors['OPPOSITION'], colors['CONTESTED'], colors
 analyst = mcolors.ListedColormap([colors['OPPOSITION'], colors['CONTESTED'], colors['TEAM']])
 
 
-excluded_vars = {'colormaps', 'colors', 'plt', 'mcolors', 'excluded_vars', 'var', 'register_cmaps'}
-colormaps = {var: eval(var) for var in dir() if not var.startswith('__') and var not in excluded_vars}
+excluded_vars = {'colormaps', 'colors', 'plt', 'mcolors', 'excluded_vars', 'var', 'register_cmaps', 'var'}
+
+colormaps = {}
+for var in dir():
+    if not var.startswith('__') and var not in excluded_vars:
+        cmap = eval(var)
+        cmap.name = var
+        colormaps[var] = cmap
 colormap_names = list(colormaps.keys())
 
 def register_cmaps():
     for var, val in globals().items():
         if not var.startswith('__') and var not in excluded_vars:
-            val.name = var
+            print(var, val)
             plt.colormaps.register(val)
-    print(plt.colormaps)
